slurminade package
==================

Module contents
---------------

.. automodule:: slurminade
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

slurminade.batch module
-----------------------

.. automodule:: slurminade.batch
   :members:
   :undoc-members:
   :show-inheritance:

slurminade.conf module
----------------------

.. automodule:: slurminade.conf
   :members:
   :undoc-members:
   :show-inheritance:

slurminade.dispatcher module
----------------------------

.. automodule:: slurminade.dispatcher
   :members:
   :undoc-members:
   :show-inheritance:

slurminade.execute module
-------------------------

.. automodule:: slurminade.execute
   :members:
   :undoc-members:
   :show-inheritance:

slurminade.function module
--------------------------

.. automodule:: slurminade.function
   :members:
   :undoc-members:
   :show-inheritance:

slurminade.function\_map module
-------------------------------

.. automodule:: slurminade.function_map
   :members:
   :undoc-members:
   :show-inheritance:

slurminade.guard module
-----------------------

.. automodule:: slurminade.guard
   :members:
   :undoc-members:
   :show-inheritance:

slurminade.options module
-------------------------

.. automodule:: slurminade.options
   :members:
   :undoc-members:
   :show-inheritance:
